==> SomatiCA_1.6.0.tar.gz: SomatiCA/man/plotSegment.Rd <==
\name{plotSegment}
\alias{plotSegment}

\title{
Plot segmentation.
}
\description{
Plot segmentation.
}
\usage{
plotSegment(segment, input, k = 1, col1 = "orange", col2 = "blue", smooth = FALSE, dev.new = TRUE, ...)
}

\arguments{
\item{segment}{
A GRanges object, segmentation result.
}
\item{input}{
A GRanges object, input for SomatiCA.
}
  \item{k}{
When there are multiple chromosomes, only kth will be plot each time.
}
  \item{col1}{
Color for data points.
}
  \item{col2}{
Color for segments.
}
  \item{smooth}{
Whether smoothed data is plotted. Default is T.
}
  \item{dev.new}{
Whether a new device will be opened.
}
  \item{\dots}{
Parameters in plot().
}
}

\value{
A plot. 
}

\author{
Mengjie Chen
}

\examples{
#data#
rawLAF <- c(rnorm(300, 0.2, 0.05), rnorm(300, 0.4, 0.05), rnorm(200, 0.3, 0.05), rnorm(200, 0.2, 0.05), rnorm(200, 0.3, 0.05), rnorm(250, 0.4, 0.05)) 
reads <- rep(50, 800+650)
chr <- c(rep("chr1", 800), rep("chr2", 650))
position <- c(c(1:800), c(1:650))
zygo <- rep("het", 800+650)
input <- GRanges(seqnames=chr, 
                 ranges=IRanges(start=position, width=1), 
                 zygosity=zygo, 
                 tCount=reads, 
                 LAF=rawLAF, 
                 tCountN=reads, 
                 gLAF=rawLAF) 
                 
#segment#
chr <- c("chr1", "chr1", "chr1", "chr2", "chr2", "chr2")
start <- c(1, 300, 600, 1, 200, 400) 
end <- c(300, 600, 800, 200, 400, 650)
medLAF <- c(0.2, 0.4, 0.3, 0.2, 0.3, 0.4)
medgermlineLAF <- rep(0.4, 6)
segment <- GRanges(seqnames=chr, 
                   ranges=IRanges(start=start, end=end), 
                   medLAF=medLAF, 
                   medgLAF=medgermlineLAF)

## First chromosome
plotSegment(segment, input, k=1)
## Second chromosome
plotSegment(segment, input, k=2)
}
\keyword{ aplot}

==> SomatiCA_2.2.1.tar.gz: SomatiCA/man/plotSegment.Rd <==
\name{plotSegment}
\alias{plotSegment}

\title{
Plot segmentation.
}
\description{
Plot segmentation.
}
\usage{
plotSegment(segment, input, k = 1, col1 = "orange", col2 = "blue", smooth = FALSE, dev.new = TRUE, cex.point =0.5, ...)
}

\arguments{
\item{segment}{
A GRanges object, segmentation result.
}
\item{input}{
A GRanges object, input for SomatiCA.
}
  \item{k}{
When there are multiple chromosomes, only kth will be plot each time.
}
  \item{col1}{
Color for data points.
}
  \item{col2}{
Color for segments.
}
  \item{smooth}{
Whether smoothed data is plotted. Default is T.
}
  \item{dev.new}{
Whether a new device will be opened.
}
  \item{cex.point}{
Size of data points.
}
  \item{\dots}{
Parameters in plot().
}
}

\value{
A plot. 
}

\author{
Mengjie Chen
}

\examples{
#data#
rawLAF <- c(rnorm(300, 0.2, 0.05), rnorm(300, 0.4, 0.05), rnorm(200, 0.3, 0.05), rnorm(200, 0.2, 0.05), rnorm(200, 0.3, 0.05), rnorm(250, 0.4, 0.05)) 
reads <- rep(50, 800+650)
chr <- c(rep("chr1", 800), rep("chr2", 650))
position <- c(c(1:800), c(1:650))
zygo <- rep("het", 800+650)
input <- GRanges(seqnames=chr, 
                 ranges=IRanges(start=position, width=1), 
                 zygosity=zygo, 
                 tCount=reads, 
                 LAF=rawLAF, 
                 tCountN=reads, 
                 gLAF=rawLAF) 
                 
#segment#
chr <- c("chr1", "chr1", "chr1", "chr2", "chr2", "chr2")
start <- c(1, 300, 600, 1, 200, 400) 
end <- c(300, 600, 800, 200, 400, 650)
medLAF <- c(0.2, 0.4, 0.3, 0.2, 0.3, 0.4)
medgermlineLAF <- rep(0.4, 6)
segment <- GRanges(seqnames=chr, 
                   ranges=IRanges(start=start, end=end), 
                   medLAF=medLAF, 
                   medgLAF=medgermlineLAF)

## First chromosome
plotSegment(segment, input, k=1)
## Second chromosome
plotSegment(segment, input, k=2)
}
\keyword{ aplot}
